# **Perceptron Python package**


## Refrence

* [Official python docs for PYPY] (https://packaging.python.org/en/latest/tutorials/packaging-projects/)


# To check packages list use
```
pip list
```
